==> certmanager-model-v1alpha3-6.3.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverFluentImpl<A extends ACMEChallengeSolverFluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverFluent<A>{
  public ACMEChallengeSolverFluentImpl() {
  }
  public ACMEChallengeSolverFluentImpl(ACMEChallengeSolver instance) {
    this.withDns01(instance.getDns01()); 
    this.withHttp01(instance.getHttp01()); 
    this.withSelector(instance.getSelector()); 
  }
  private ACMEChallengeSolverDNS01Builder dns01;
  private ACMEChallengeSolverHTTP01Builder http01;
  private CertificateDNSNameSelectorBuilder selector;
  
  /**
   * This method has been deprecated, please use method buildDns01 instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverDNS01 getDns01() {
    return this.dns01!=null ?this.dns01.build():null;
  }
  public ACMEChallengeSolverDNS01 buildDns01() {
    return this.dns01!=null ?this.dns01.build():null;
  }
  public A withDns01(ACMEChallengeSolverDNS01 dns01) {
    _visitables.get("dns01").remove(this.dns01);
    if (dns01!=null){ this.dns01= new ACMEChallengeSolverDNS01Builder(dns01); _visitables.get("dns01").add(this.dns01);} else { this.dns01 = null; _visitables.get("dns01").remove(this.dns01); } return (A) this;
  }
  public Boolean hasDns01() {
    return this.dns01 != null;
  }
  public ACMEChallengeSolverFluent.Dns01Nested<A> withNewDns01() {
    return new ACMEChallengeSolverFluentImpl.Dns01NestedImpl();
  }
  public ACMEChallengeSolverFluent.Dns01Nested<A> withNewDns01Like(ACMEChallengeSolverDNS01 item) {
    return new ACMEChallengeSolverFluentImpl.Dns01NestedImpl(item);
  }
  public ACMEChallengeSolverFluent.Dns01Nested<A> editDns01() {
    return withNewDns01Like(getDns01());
  }
  public ACMEChallengeSolverFluent.Dns01Nested<A> editOrNewDns01() {
    return withNewDns01Like(getDns01() != null ? getDns01(): new ACMEChallengeSolverDNS01Builder().build());
  }
  public ACMEChallengeSolverFluent.Dns01Nested<A> editOrNewDns01Like(ACMEChallengeSolverDNS01 item) {
    return withNewDns01Like(getDns01() != null ? getDns01(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildHttp01 instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01 getHttp01() {
    return this.http01!=null ?this.http01.build():null;
  }
  public ACMEChallengeSolverHTTP01 buildHttp01() {
    return this.http01!=null ?this.http01.build():null;
  }
  public A withHttp01(ACMEChallengeSolverHTTP01 http01) {
    _visitables.get("http01").remove(this.http01);
    if (http01!=null){ this.http01= new ACMEChallengeSolverHTTP01Builder(http01); _visitables.get("http01").add(this.http01);} else { this.http01 = null; _visitables.get("http01").remove(this.http01); } return (A) this;
  }
  public Boolean hasHttp01() {
    return this.http01 != null;
  }
  public ACMEChallengeSolverFluent.Http01Nested<A> withNewHttp01() {
    return new ACMEChallengeSolverFluentImpl.Http01NestedImpl();
  }
  public ACMEChallengeSolverFluent.Http01Nested<A> withNewHttp01Like(ACMEChallengeSolverHTTP01 item) {
    return new ACMEChallengeSolverFluentImpl.Http01NestedImpl(item);
  }
  public ACMEChallengeSolverFluent.Http01Nested<A> editHttp01() {
    return withNewHttp01Like(getHttp01());
  }
  public ACMEChallengeSolverFluent.Http01Nested<A> editOrNewHttp01() {
    return withNewHttp01Like(getHttp01() != null ? getHttp01(): new ACMEChallengeSolverHTTP01Builder().build());
  }
  public ACMEChallengeSolverFluent.Http01Nested<A> editOrNewHttp01Like(ACMEChallengeSolverHTTP01 item) {
    return withNewHttp01Like(getHttp01() != null ? getHttp01(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public CertificateDNSNameSelector getSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public CertificateDNSNameSelector buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public A withSelector(CertificateDNSNameSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new CertificateDNSNameSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  public Boolean hasSelector() {
    return this.selector != null;
  }
  public ACMEChallengeSolverFluent.SelectorNested<A> withNewSelector() {
    return new ACMEChallengeSolverFluentImpl.SelectorNestedImpl();
  }
  public ACMEChallengeSolverFluent.SelectorNested<A> withNewSelectorLike(CertificateDNSNameSelector item) {
    return new ACMEChallengeSolverFluentImpl.SelectorNestedImpl(item);
  }
  public ACMEChallengeSolverFluent.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public ACMEChallengeSolverFluent.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new CertificateDNSNameSelectorBuilder().build());
  }
  public ACMEChallengeSolverFluent.SelectorNested<A> editOrNewSelectorLike(CertificateDNSNameSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEChallengeSolverFluentImpl that = (ACMEChallengeSolverFluentImpl) o;
    if (dns01 != null ? !dns01.equals(that.dns01) :that.dns01 != null) return false;
    if (http01 != null ? !http01.equals(that.http01) :that.http01 != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(dns01,  http01,  selector,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (dns01 != null) { sb.append("dns01:"); sb.append(dns01 + ","); }
    if (http01 != null) { sb.append("http01:"); sb.append(http01 + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector); }
    sb.append("}");
    return sb.toString();
  }
  class Dns01NestedImpl<N> extends ACMEChallengeSolverDNS01FluentImpl<ACMEChallengeSolverFluent.Dns01Nested<N>> implements ACMEChallengeSolverFluent.Dns01Nested<N>,Nested<N>{
    Dns01NestedImpl(ACMEChallengeSolverDNS01 item) {
      this.builder = new ACMEChallengeSolverDNS01Builder(this, item);
    }
    Dns01NestedImpl() {
      this.builder = new ACMEChallengeSolverDNS01Builder(this);
    }
    ACMEChallengeSolverDNS01Builder builder;
    public N and() {
      return (N) ACMEChallengeSolverFluentImpl.this.withDns01(builder.build());
    }
    public N endDns01() {
      return and();
    }
    
  }
  class Http01NestedImpl<N> extends ACMEChallengeSolverHTTP01FluentImpl<ACMEChallengeSolverFluent.Http01Nested<N>> implements ACMEChallengeSolverFluent.Http01Nested<N>,Nested<N>{
    Http01NestedImpl(ACMEChallengeSolverHTTP01 item) {
      this.builder = new ACMEChallengeSolverHTTP01Builder(this, item);
    }
    Http01NestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01Builder(this);
    }
    ACMEChallengeSolverHTTP01Builder builder;
    public N and() {
      return (N) ACMEChallengeSolverFluentImpl.this.withHttp01(builder.build());
    }
    public N endHttp01() {
      return and();
    }
    
  }
  class SelectorNestedImpl<N> extends CertificateDNSNameSelectorFluentImpl<ACMEChallengeSolverFluent.SelectorNested<N>> implements ACMEChallengeSolverFluent.SelectorNested<N>,Nested<N>{
    SelectorNestedImpl(CertificateDNSNameSelector item) {
      this.builder = new CertificateDNSNameSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new CertificateDNSNameSelectorBuilder(this);
    }
    CertificateDNSNameSelectorBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverFluentImpl<A extends ACMEChallengeSolverFluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverFluent<A>{
  public ACMEChallengeSolverFluentImpl() {
  }
  public ACMEChallengeSolverFluentImpl(ACMEChallengeSolver instance) {
    if (instance != null) {
      this.withDns01(instance.getDns01());
      this.withHttp01(instance.getHttp01());
      this.withSelector(instance.getSelector());
    }
  }
  private ACMEChallengeSolverDNS01Builder dns01;
  private ACMEChallengeSolverHTTP01Builder http01;
  private CertificateDNSNameSelectorBuilder selector;
  
  /**
   * This method has been deprecated, please use method buildDns01 instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverDNS01 getDns01() {
    return this.dns01!=null ?this.dns01.build():null;
  }
  public ACMEChallengeSolverDNS01 buildDns01() {
    return this.dns01!=null ?this.dns01.build():null;
  }
  public A withDns01(ACMEChallengeSolverDNS01 dns01) {
    _visitables.get("dns01").remove(this.dns01);
    if (dns01!=null){ this.dns01= new ACMEChallengeSolverDNS01Builder(dns01); _visitables.get("dns01").add(this.dns01);} else { this.dns01 = null; _visitables.get("dns01").remove(this.dns01); } return (A) this;
  }
  public Boolean hasDns01() {
    return this.dns01 != null;
  }
  public ACMEChallengeSolverFluentImpl.Dns01Nested<A> withNewDns01() {
    return new ACMEChallengeSolverFluentImpl.Dns01NestedImpl();
  }
  public ACMEChallengeSolverFluentImpl.Dns01Nested<A> withNewDns01Like(ACMEChallengeSolverDNS01 item) {
    return new ACMEChallengeSolverFluentImpl.Dns01NestedImpl(item);
  }
  public ACMEChallengeSolverFluentImpl.Dns01Nested<A> editDns01() {
    return withNewDns01Like(getDns01());
  }
  public ACMEChallengeSolverFluentImpl.Dns01Nested<A> editOrNewDns01() {
    return withNewDns01Like(getDns01() != null ? getDns01(): new ACMEChallengeSolverDNS01Builder().build());
  }
  public ACMEChallengeSolverFluentImpl.Dns01Nested<A> editOrNewDns01Like(ACMEChallengeSolverDNS01 item) {
    return withNewDns01Like(getDns01() != null ? getDns01(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildHttp01 instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01 getHttp01() {
    return this.http01!=null ?this.http01.build():null;
  }
  public ACMEChallengeSolverHTTP01 buildHttp01() {
    return this.http01!=null ?this.http01.build():null;
  }
  public A withHttp01(ACMEChallengeSolverHTTP01 http01) {
    _visitables.get("http01").remove(this.http01);
    if (http01!=null){ this.http01= new ACMEChallengeSolverHTTP01Builder(http01); _visitables.get("http01").add(this.http01);} else { this.http01 = null; _visitables.get("http01").remove(this.http01); } return (A) this;
  }
  public Boolean hasHttp01() {
    return this.http01 != null;
  }
  public ACMEChallengeSolverFluentImpl.Http01Nested<A> withNewHttp01() {
    return new ACMEChallengeSolverFluentImpl.Http01NestedImpl();
  }
  public ACMEChallengeSolverFluentImpl.Http01Nested<A> withNewHttp01Like(ACMEChallengeSolverHTTP01 item) {
    return new ACMEChallengeSolverFluentImpl.Http01NestedImpl(item);
  }
  public ACMEChallengeSolverFluentImpl.Http01Nested<A> editHttp01() {
    return withNewHttp01Like(getHttp01());
  }
  public ACMEChallengeSolverFluentImpl.Http01Nested<A> editOrNewHttp01() {
    return withNewHttp01Like(getHttp01() != null ? getHttp01(): new ACMEChallengeSolverHTTP01Builder().build());
  }
  public ACMEChallengeSolverFluentImpl.Http01Nested<A> editOrNewHttp01Like(ACMEChallengeSolverHTTP01 item) {
    return withNewHttp01Like(getHttp01() != null ? getHttp01(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public CertificateDNSNameSelector getSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public CertificateDNSNameSelector buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public A withSelector(CertificateDNSNameSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new CertificateDNSNameSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  public Boolean hasSelector() {
    return this.selector != null;
  }
  public ACMEChallengeSolverFluentImpl.SelectorNested<A> withNewSelector() {
    return new ACMEChallengeSolverFluentImpl.SelectorNestedImpl();
  }
  public ACMEChallengeSolverFluentImpl.SelectorNested<A> withNewSelectorLike(CertificateDNSNameSelector item) {
    return new ACMEChallengeSolverFluentImpl.SelectorNestedImpl(item);
  }
  public ACMEChallengeSolverFluentImpl.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public ACMEChallengeSolverFluentImpl.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new CertificateDNSNameSelectorBuilder().build());
  }
  public ACMEChallengeSolverFluentImpl.SelectorNested<A> editOrNewSelectorLike(CertificateDNSNameSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverFluentImpl that = (ACMEChallengeSolverFluentImpl) o;
    if (!java.util.Objects.equals(dns01, that.dns01)) return false;

    if (!java.util.Objects.equals(http01, that.http01)) return false;

    if (!java.util.Objects.equals(selector, that.selector)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(dns01,  http01,  selector,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (dns01 != null) { sb.append("dns01:"); sb.append(dns01 + ","); }
    if (http01 != null) { sb.append("http01:"); sb.append(http01 + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector); }
    sb.append("}");
    return sb.toString();
  }
  class Dns01NestedImpl<N> extends ACMEChallengeSolverDNS01FluentImpl<ACMEChallengeSolverFluentImpl.Dns01Nested<N>> implements ACMEChallengeSolverFluentImpl.Dns01Nested<N>,Nested<N>{
    Dns01NestedImpl(ACMEChallengeSolverDNS01 item) {
      this.builder = new ACMEChallengeSolverDNS01Builder(this, item);
    }
    Dns01NestedImpl() {
      this.builder = new ACMEChallengeSolverDNS01Builder(this);
    }
    ACMEChallengeSolverDNS01Builder builder;
    public N and() {
      return (N) ACMEChallengeSolverFluentImpl.this.withDns01(builder.build());
    }
    public N endDns01() {
      return and();
    }
    
  }
  class Http01NestedImpl<N> extends ACMEChallengeSolverHTTP01FluentImpl<ACMEChallengeSolverFluentImpl.Http01Nested<N>> implements ACMEChallengeSolverFluentImpl.Http01Nested<N>,Nested<N>{
    Http01NestedImpl(ACMEChallengeSolverHTTP01 item) {
      this.builder = new ACMEChallengeSolverHTTP01Builder(this, item);
    }
    Http01NestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01Builder(this);
    }
    ACMEChallengeSolverHTTP01Builder builder;
    public N and() {
      return (N) ACMEChallengeSolverFluentImpl.this.withHttp01(builder.build());
    }
    public N endHttp01() {
      return and();
    }
    
  }
  class SelectorNestedImpl<N> extends CertificateDNSNameSelectorFluentImpl<ACMEChallengeSolverFluentImpl.SelectorNested<N>> implements ACMEChallengeSolverFluentImpl.SelectorNested<N>,Nested<N>{
    SelectorNestedImpl(CertificateDNSNameSelector item) {
      this.builder = new CertificateDNSNameSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new CertificateDNSNameSelectorBuilder(this);
    }
    CertificateDNSNameSelectorBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}
